@@ -1,4 +1,4 @@
-/* DadaDodo, Copyright (c) 1997, 1998 Jamie Zawinski <jwz@netscape.com>
+/* DadaDodo, Copyright (c) 1997, 1998 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -154,10 +154,10 @@ static entity entities[] = {
 };
 
 static char
-get_entity (const char *string, int length)
+get_entity (const unsigned char *string, int length)
 {
   int i;
-  char c = *string;
+  unsigned char c = *string;
   for (i = 0; i < (sizeof(entities)/sizeof(*entities)); i++)
     if (length == entities[i].length &&
 	c == entities[i].string[0] &&
@@ -182,8 +182,8 @@ scan (FILE *file, hash_table *table, char *first_line)
   pword *prev = 0;
   int line_tick = 0;
   int line_count = 0;
-  char buf [10240];
-  char *s;
+  unsigned char buf [10240];
+  unsigned char *s;
   int L;
   int mailbox_p = 0;
   int in_headers = 0;
@@ -193,8 +193,8 @@ scan (FILE *file, hash_table *table, char *first_line)
   int in_comment_p = 0;
   int in_sig_p = 0;
 
-  char *qp_wrap_hack = 0;
-  char *qp_free_wrap_hack = 0;
+  unsigned char *qp_wrap_hack = 0;
+  unsigned char *qp_free_wrap_hack = 0;
 
   if (first_line)
     s = first_line;
@@ -215,7 +215,7 @@ scan (FILE *file, hash_table *table, char *first_line)
 	}
       if (qp_wrap_hack)
 	{
-	  qp_free_wrap_hack = (char *)
+	  qp_free_wrap_hack = (unsigned char *)
 	    malloc (strlen(s)+strlen(qp_wrap_hack)+1);
 	  if (!qp_free_wrap_hack) return -1;
 	  strcpy(qp_free_wrap_hack, qp_wrap_hack);
@@ -312,7 +312,7 @@ scan (FILE *file, hash_table *table, char *first_line)
 	  /* Strip off those FUCKING VCARDS too. */
 	  if ((*s == 'b' || *s == 'B') && !strncasecmp(s, "begin:", 6))
 	    {
-	      char *s2 = s+6;
+	      unsigned char *s2 = s+6;
 	      while (isspace(*s2)) s2++;
 	      if (!strncasecmp(s2, "vcard", 5))
 		{
@@ -328,7 +328,7 @@ scan (FILE *file, hash_table *table, char *first_line)
 	  /* Strip off anything that looks like a citation prefix. */
 	  {
 	    int got_some = 0;
-	    char *s2 = s;
+	    unsigned char *s2 = s;
 	    while (isspace(*s2))
 	      s2++;
 	    while (*s2 == '>' || *s2 == ']' || *s2 == '}' ||
@@ -354,8 +354,8 @@ scan (FILE *file, hash_table *table, char *first_line)
 
 	  /* Strip off anything that looks like a citation heading. */
 	  {
-	    const char *w1 = "wrote:";
-	    const char *w2 = "writes:";
+	    const unsigned char *w1 = "wrote:";
+	    const unsigned char *w2 = "writes:";
 	    if (L > 10 && (strstr(s+L-10, w1) || strstr(s+L-10, w2)))
 	      {
 		int got_it = 0;
@@ -365,7 +365,7 @@ scan (FILE *file, hash_table *table, char *first_line)
 		   o  the line contains "@"; or
 		   o  the line contains less than 4 spaces.
 		 */
-		char *s2 = s;
+		unsigned char *s2 = s;
 		while (*s2 == ' ') s2++;
 		if (!strncmp(s2, "In ", 3) || !strncmp(s2, "On ", 3))
 		  got_it = 1;
@@ -440,7 +440,7 @@ scan (FILE *file, hash_table *table, char *first_line)
 		    ;
 		  else
 		    {
-		      const char *s2;
+		      const unsigned char *s2;
 		      /* Lines that look like they begin with a header field
 			 (match "^[^ \t\n]+:") don't mean end of headers. */
 		      for (s2 = s; *s2 && *s2 != ':' && !isspace(*s2); s2++)
@@ -481,7 +481,7 @@ scan (FILE *file, hash_table *table, char *first_line)
 	  if (L == 61 && *s == 'M')
 	    {
 	      int uue_p = 1;
-	      const char *s2;
+	      const unsigned char *s2;
 	      for (s2 = s; *s2 && *s2 != '\n' && *s2 != '\r'; s2++)
 		if (*s2 < ' ' || *s2 > '`')
 		  {
@@ -503,7 +503,7 @@ scan (FILE *file, hash_table *table, char *first_line)
 	  if (L >= 60 || (L > 3 && s[L-1] == '='))
 	    {
 	      int b64_p = 1;
-	      const char *s2;
+	      const unsigned char *s2;
 	      for (s2 = s; *s2 && *s2 != '\n' && *s2 != '\r'; s2++)
 		if (! ((*s2 >= 'A' && *s2 <= 'Z') ||
 		       (*s2 >= 'a' && *s2 <= 'z') ||
@@ -550,17 +550,17 @@ scan (FILE *file, hash_table *table, char *first_line)
       {
 #ifdef DEBUG_QP
 	int got_any = 0;
-	char *o = strdup(s);
+	unsigned char *o = strdup(s);
 #endif
-	char *s2 = s;
+	unsigned char *s2 = s;
 	while ((s2 = strchr(s2, '=')))
 	  {
 	    if (!isxdigit(s2[1]) || !isxdigit(s2[2]))
 	      s2++;
 	    else if (*s2)
 	      {
-		char *s3 = s2 + 1;
-		const char *s4 = s2 + 3;
+		unsigned char *s3 = s2 + 1;
+		const unsigned char *s4 = s2 + 3;
 		s2[0] = ((((s2[1] >= '0' && s2[1] <= '9')
 			   ? s2[1] - '0'
 			   : ((s2[1] >= 'A' && s2[1] <= 'F')
@@ -600,7 +600,7 @@ scan (FILE *file, hash_table *table, char *first_line)
 	  s[L-1] == '=' &&
 	  isalnum(s[L-2]))
 	{
-	  char *s3 = s+L-2;
+	  unsigned char *s3 = s+L-2;
 	  s[L-1] = 0;
 	  while (isalnum(*s3) && s3 > s)
 	    s3--;
@@ -614,14 +614,14 @@ scan (FILE *file, hash_table *table, char *first_line)
       {
 #ifdef DEBUG_HTML
 	int got_any = 0;
-	char *o = strdup(s);
+	unsigned char *o = strdup(s);
 #endif
 
-	const char *last = s;
-	char *s2;
+	const unsigned char *last = s;
+	unsigned char *s2;
 	while ((s2 = strchr(last, '<')))
 	  {
-	    const char *s3 = s2+1;
+	    const unsigned char *s3 = s2+1;
 	    int close_p = 0;
 
 	    last = s3;
@@ -664,10 +664,10 @@ scan (FILE *file, hash_table *table, char *first_line)
 		  }
 		else
 		  {
-		    char *out = s2;
+		    unsigned char *out = s2;
 
 #ifdef DEBUG_HTML
-		    char b[255];
+		    unsigned char b[255];
 		    strncpy(b, s2, s3+1-s2);
 		    b[s3+1-s2]=0;
 		    printf ("HTML: %s\n", b);
@@ -686,7 +686,7 @@ scan (FILE *file, hash_table *table, char *first_line)
 	      }
 	    else if (s3[0] == '!' && s3[1] == '-' && s3[2] == '-')
 	      {
-		char *out = s2;
+		unsigned char *out = s2;
 		in_comment_p = 1;
 		s2[0] = 0;
 		s2[1] = 0;
@@ -725,17 +725,17 @@ scan (FILE *file, hash_table *table, char *first_line)
 
       /* Remap anything that looks like an HTML character entity. */
       {
-	const char *last = s;
-	char *s2;
+	const unsigned char *last = s;
+	unsigned char *s2;
 	while ((s2 = strchr(last, '&')))
 	  {
-	    char *s3 = s2+1;
+	    unsigned char *s3 = s2+1;
 	    last = s3;
 	    while (*s3 && *s3 != ';' && !isspace(*s3) && s3 < last+10)
 	      s3++;
 	    if (*s3 == ';' || isspace(*s3))
 	      {
-		char e = get_entity(last, s3-last);
+		unsigned char e = get_entity(last, s3-last);
 		if (!e) continue;
 		*s2++ = e;
 		if (*s3) s3++;
@@ -793,7 +793,7 @@ the text files each time.\n\n");
 extern int *starters;
 extern int total_starters;
 extern word *all_words;
-extern char **all_strings;
+extern unsigned char **all_strings;
 
 int
 main (int argc, char **argv)
@@ -831,10 +831,20 @@ main (int argc, char **argv)
 	}
       else if (!strcmp(sw, "-c") || !strcmp(sw, "-count"))
 	{
+          if (i+1 >= argc)
+            {
+              usage(argv[0]);
+              exit(1);
+            }
 	  count = atoi(argv[++i]);
 	}
       else if (!strcmp(sw, "-p") || !strcmp(sw, "-pause"))
 	{
+          if (i+1 >= argc)
+            {
+              usage(argv[0]);
+              exit(1);
+            }
 	  pause = atoi(argv[++i]);
 	}
       else if (!strcmp(sw, "-html"))
@@ -886,8 +896,8 @@ main (int argc, char **argv)
 
       for (i = 0; i < n_input; i++)
 	{
-	  char buf[1024];
-	  char *s;
+	  unsigned char buf[1024];
+	  unsigned char *s;
 	  FILE *f;
 	  if (!strcmp(input[i], "-"))
 	    f = stdin;
@@ -896,7 +906,6 @@ main (int argc, char **argv)
 	      f = fopen (input[i], "r");
 	      if (!f)
 		{
-		  char buf[255];
 		  sprintf(buf, "%s: opening input file %s", argv[0], input[i]);
 		  perror(buf);
 		  exit(1);
@@ -1061,7 +1070,7 @@ main (int argc, char **argv)
 	}
       else
 	{
-	  char *s = strtok (stat_words, ",; ");
+	  unsigned char *s = strtok (stat_words, ",; ");
 	  int done_once = 0;
 	  do
 	    {
