@@ -1,5 +1,5 @@
 /* generate.h --- generating random sentences from a markov chain.
- * DadaDodo, Copyright (c) 1997 Jamie Zawinski <jwz@netscape.com>
+ * DadaDodo, Copyright (c) 1997, 2003 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -18,7 +18,8 @@
 extern int random_sentence (FILE *stream, int *column,
 			    int indent, int fill_column, int html_p);
 extern void word_stats (FILE *stream, word *word);
-extern void string_stats (FILE *stream, const char *word, int print_header);
+extern void string_stats (FILE *stream, const unsigned char *word,
+                          int print_header);
 extern void stats (FILE *stream);
 
 #endif /* __DADADODO_GENERATE_H__ */
