@@ -1,5 +1,5 @@
 /* hash.c --- simple hash tables.
- * DadaDodo, Copyright (c) 1997 Jamie Zawinski <jwz@netscape.com>
+ * DadaDodo, Copyright (c) 1997, 2003 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -28,7 +28,7 @@ int maphash (hash_table *table,
 	     int (*mapper) (const void *key, const void *value, void *arg),
 	     void *arg);
 
-unsigned long string_hash (const char *string);
-unsigned long string_case_hash (const char *string);
+unsigned long string_hash (const unsigned char *string);
+unsigned long string_case_hash (const unsigned char *string);
 
 #endif /* __DADADODO_HASH_H__ */
